Exception: IosAppAttest::AppIdentityError

Inherits:
VerificationError show all
Defined in:
lib/ios_app_attest/errors.rb

Overview

Error raised when app identity validation fails

This error is raised when there are issues with the app identity during the verification process, such as ID mismatch or invalid format.

Direct Known Subclasses

IdMismatch, InvalidFormat

Defined Under Namespace

Classes: IdMismatch, InvalidFormat