Exception: IosAppAttest::ChallengeError

Inherits:
VerificationError show all
Defined in:
lib/ios_app_attest/errors.rb

Overview

Error raised when challenge validation fails

This error is raised when there are issues with the challenge during the verification process, such as invalid signature, invalid format, or key ID mismatch.

Direct Known Subclasses

InvalidFormat, InvalidSignature, KeyIdMismatch

Defined Under Namespace

Classes: InvalidFormat, InvalidSignature, KeyIdMismatch