Exception: IosAppAttest::AttestationError
- Inherits:
-
VerificationError
- Object
- StandardError
- Error
- VerificationError
- IosAppAttest::AttestationError
- Defined in:
- lib/ios_app_attest/errors.rb
Overview
Error raised when attestation format is invalid
This error is raised when there are issues with the attestation format during the verification process, such as invalid structure or missing data.
Direct Known Subclasses
Defined Under Namespace
Classes: InvalidStructure, MissingData