Exception: IosAppAttest::ChallengeError
- Inherits:
-
VerificationError
- Object
- StandardError
- Error
- VerificationError
- IosAppAttest::ChallengeError
- Defined in:
- lib/ios_app_attest/errors.rb
Overview
Error raised when challenge validation fails
This error is raised when there are issues with the challenge during the verification process, such as invalid signature, invalid format, or key ID mismatch.
Direct Known Subclasses
Defined Under Namespace
Classes: InvalidFormat, InvalidSignature, KeyIdMismatch