Exception: IosAppAttest::NonceError
- Inherits:
-
VerificationError
- Object
- StandardError
- Error
- VerificationError
- IosAppAttest::NonceError
- Defined in:
- lib/ios_app_attest/errors.rb
Overview
Error raised when nonce validation fails
This error is raised when there are issues with the challenge nonce during the verification process, such as expired, already used, or not found nonces.
Direct Known Subclasses
Defined Under Namespace
Classes: AlreadyUsed, Expired, NotFound